diff -r e0cfab501dd1 -r 8d73e94b3790 src/http/ngx_http_core_module.c
--- a/src/http/ngx_http_core_module.c   Tue May 31 00:14:11 2022 +0300
+++ b/src/http/ngx_http_core_module.c   Sun Jun 05 16:59:52 2022 +0530
@@ -252,6 +252,13 @@
       offsetof(ngx_http_core_srv_conf_t, large_client_header_buffers),
       NULL },
 
+    { ngx_string("resolve_cname"),
+      NGX_HTTP_MAIN_CONF|NGX_CONF_FLAG,
+      ngx_conf_set_flag_slot,
+      NGX_HTTP_MAIN_CONF_OFFSET,
+      offsetof(ngx_http_core_main_conf_t, resolve_cname),
+      NULL },
+
     { ngx_string("ignore_invalid_headers"),
       NGX_HTTP_MAIN_CONF|NGX_HTTP_SRV_CONF|NGX_CONF_FLAG,
       ngx_conf_set_flag_slot,
@@ -3404,6 +3411,7 @@
     cmcf->variables_hash_max_size = NGX_CONF_UNSET_UINT;
     cmcf->variables_hash_bucket_size = NGX_CONF_UNSET_UINT;
 
+    cmcf->resolve_cname = NGX_CONF_UNSET;
     return cmcf;
 }
 
diff -r e0cfab501dd1 -r 8d73e94b3790 src/http/ngx_http_core_module.h
--- a/src/http/ngx_http_core_module.h   Tue May 31 00:14:11 2022 +0300
+++ b/src/http/ngx_http_core_module.h   Sun Jun 05 16:59:52 2022 +0530
@@ -172,6 +172,8 @@
 
     ngx_array_t               *ports;
 
+    ngx_flag_t                 resolve_cname;
+
     ngx_http_phase_t           phases[NGX_HTTP_LOG_PHASE + 1];
 } ngx_http_core_main_conf_t;
 
diff -r e0cfab501dd1 -r 8d73e94b3790 src/http/ngx_http_request.c
--- a/src/http/ngx_http_request.c       Tue May 31 00:14:11 2022 +0300
+++ b/src/http/ngx_http_request.c       Sun Jun 05 16:59:52 2022 +0530
@@ -8,6 +8,7 @@
 #include <ngx_config.h>
 #include <ngx_core.h>
 #include <ngx_http.h>
+#include<netdb.h>
 
 
 static void ngx_http_wait_request_handler(ngx_event_t *ev);
@@ -36,6 +37,8 @@
 static ngx_int_t ngx_http_find_virtual_server(ngx_connection_t *c,
     ngx_http_virtual_names_t *virtual_names, ngx_str_t *host,
     ngx_http_request_t *r, ngx_http_core_srv_conf_t **cscfp);
+    
+static void ngx_http_find_cname(ngx_str_t* host, ngx_str_t* cname, ngx_http_request_t *r);
 
 static void ngx_http_request_handler(ngx_event_t *ev);
 static void ngx_http_terminate_request(ngx_http_request_t *r, ngx_int_t rc);
@@ -2269,6 +2272,27 @@
     return NGX_OK;
 }
 
+static void
+ngx_http_find_cname(ngx_str_t* host, ngx_str_t* cname, ngx_http_request_t *r)
+{
+    struct hostent *he;
+    char **alias_list;
+
+    if ( (he = gethostbyname( (char*) host->data ) ) == NULL) {
+        return;
+    }
+
+    alias_list = (char **) he->h_aliases;
+
+    for(int i = 0; alias_list[i] != NULL; i++) {
+        if (alias_list[i+1] == NULL) {
+            cname->data = (u_char *) alias_list[i];
+            cname->len = ngx_strlen(cname->data);
+        }
+    }
+    ngx_log_debug2(NGX_LOG_DEBUG_HTTP, r->connection->log, 0,
+                   "Host - %s cnamed to %s", host->data, cname->data);
+}
 
 static ngx_int_t
 ngx_http_find_virtual_server(ngx_connection_t *c,
@@ -2290,6 +2314,24 @@
         return NGX_OK;
     }
 
+    ngx_http_core_main_conf_t *cmcf;
+
+    cmcf = ngx_http_get_module_main_conf(r, ngx_http_core_module);
+
+    if(cmcf->resolve_cname) {
+        ngx_str_t cname = ngx_null_string;
+        ngx_http_find_cname(host, &cname, r);
+        if (cname.data != NULL) {
+            cscf = ngx_hash_find_combined(&virtual_names->names,
+                                      ngx_hash_key(cname.data, cname.len),
+                                      cname.data, cname.len);
+            if (cscf) {
+                *cscfp = cscf;
+                return NGX_OK;
+            }
+        }
+    }
+
 #if (NGX_PCRE)
 
     if (host->len && virtual_names->nregex) {
